@@ -399,32 +399,43 @@ class MWACorrFITS(UVData):
         num_start_flag = int(start_flag / self.integration_time[0])
         num_end_flag = int(end_flag / self.integration_time[0])
 
+        shape = self.flag_array.shape
+        reshape = [self.Ntimes, self.Nbls, self.Nfreqs, self.Npols]
+
+        self.flag_array = (
+            self.flag_array
+            if (shape == reshape)
+            else np.reshape(self.flag_array, reshape,)
+        )
+
+        bad_chan_inds = []
         if num_ch_flag > 0:
-            edge_inds = []
             for ch_count in range(num_ch_flag):
                 # count up from the left
                 left_chans = list(range(ch_count, self.Nfreqs, num_fine_chan))
                 # count down from the right
                 right_chans = list(range(self.Nfreqs - 1 - ch_count, 0, -num_fine_chan))
-                edge_inds = edge_inds + left_chans + right_chans
-
-            self.flag_array[:, edge_inds, :] = True
+                bad_chan_inds += left_chans + right_chans
 
         if flag_dc_offset:
-            center_inds = list(range(num_fine_chan // 2, self.Nfreqs, num_fine_chan))
+            bad_chan_inds += list(range(num_fine_chan // 2, self.Nfreqs, num_fine_chan))
 
-            self.flag_array[:, center_inds, :] = True
+        if len(bad_chan_inds) != 0:
+            self.flag_array[:, :, bad_chan_inds, :] = True
 
         if (num_start_flag > 0) or (num_end_flag > 0):
-            shape = self.flag_array.shape
-            reshape = [self.Ntimes, self.Nbls, self.Nfreqs, self.Npols]
-            self.flag_array = np.reshape(self.flag_array, reshape)
             if num_start_flag > 0:
-                self.flag_array[:num_start_flag, :, :, :] = True
+                self.flag_array[:num_start_flag] = True
             if num_end_flag > 0:
-                self.flag_array[-num_end_flag:, :, :, :] = True
+                self.flag_array[-num_end_flag:] = True
             self.flag_array = np.reshape(self.flag_array, shape)
 
+        self.flag_array = (
+            self.flag_array
+            if (shape == reshape)
+            else np.reshape(self.flag_array, shape,)
+        )
+
     def _read_fits_file(
         self,
         filename,
@@ -1072,6 +1083,8 @@ class MWACorrFITS(UVData):
         check_extra=True,
         run_check_acceptability=True,
         strict_uvw_antpos_check=False,
+        check_autos=True,
+        fix_autos=True,
     ):
         """
         Read in MWA correlator gpu box files.
@@ -1178,6 +1191,12 @@ class MWACorrFITS(UVData):
         strict_uvw_antpos_check : bool
             Option to raise an error rather than a warning if the check that
             uvws match antenna positions does not pass.
+        check_autos : bool
+            Check whether any auto-correlations have non-zero imaginary values in
+            data_array (which should not mathematically exist). Default is True.
+        fix_autos : bool
+            If auto-correlations with imaginary values are found, fix those values so
+            that they are real-only in data_array. Default is True.
 
 
         Raises
@@ -1685,6 +1704,15 @@ class MWACorrFITS(UVData):
             else:
                 self.flag_array = np.repeat(self.flag_array, num_fine_chans, axis=2)
 
+            if flag_init:
+                self.flag_init(
+                    num_fine_chans,
+                    edge_width=edge_width,
+                    start_flag=start_flag,
+                    end_flag=end_flag,
+                    flag_dc_offset=flag_dc_offset,
+                )
+
             # flag bad ants
             bad_ant_inds = np.logical_or(
                 np.isin(ant_1_inds[: self.Nbls], flagged_ant_inds),
@@ -1770,15 +1798,6 @@ class MWACorrFITS(UVData):
                 for filename in file_dict["flags"]:
                     self._read_flag_file(filename, file_nums, num_fine_chans)
 
-            if flag_init:
-                self.flag_init(
-                    num_fine_chans,
-                    edge_width=edge_width,
-                    start_flag=start_flag,
-                    end_flag=end_flag,
-                    flag_dc_offset=flag_dc_offset,
-                )
-
             # to account for discrepancies between file conventions, in order
             # to be consistent with the uvw vector direction, all the data must
             # be conjugated
@@ -1809,4 +1828,6 @@ class MWACorrFITS(UVData):
                 run_check_acceptability=run_check_acceptability,
                 strict_uvw_antpos_check=strict_uvw_antpos_check,
                 allow_flip_conj=True,
+                check_autos=check_autos,
+                fix_autos=fix_autos,
             )
